# Brickproof

Testing suite for integrating Databricks tests into CI/CD workflows.


# Installation

```sh
pip install brickproof
```

# Use

## Initialize Project

To initialize a brickproof project, run:

```sh
brickproof init
```

This will create a new `brickproof.toml` file, which you will edit for your own usecase. Running the `init` command multiple times will not overwrite your `brickproof.toml` file.


## Configre Databricks Connection

To configure connection credentials to your Databricks workspace, run:

```sh

brickproof configure

```

This command will prompt you to enter your databricks workspace url, personal access token, and profile name. These
will be written out to a `.bprc` file in your local directory. 

## Run Brickproof

To run a brickproof testing event, run:

```sh
brickproof run
```

To run with a specific configured profile, run:

```sh
brickproof run --p <MY_PROFILE>
```

## Version

To get the version of your brickproof instance, run:

```sh
brickproof version

```


# Config

## Brickproof.toml

Here is an example `brickproof.toml` file. 

```
[repo]
name = "brickproof"
workspace_path = "/Workspace/Users/jordan.m.young0@gmail.com"
git_provider = "gitHub"
git_repo = "https://github.com/Jordan-M-Young/brickproof.git"
branch = "main"

[job]
job_name = "Brickproof-Test"
task_key = "Unittests"
dependencies = ["requests","tomlkit"]
runner = "default"
```
This is the main configuration file you'll control your testing setup with.
There are two main sections `[repo]` and `[job]`. These sections contain configuration variables for your code base and 
testing job specifications respectively. Below we'll go into more detail on the variables.

### repo

- `name` : the name of directory your git repo will be cloned into on databricks
- `workspace_path` : the base workspace directory where brickproof files will live during the job
- `git_provider` : the place your repo lives. Valid values include: `gitHub`, `bitbucketCloud`, `gitLab`, `azureDevOpsServices`, `gitHubEnterprise`, `bitbucketServer`, `gitLabEnterpriseEdition` and `awsCodeCommit`
- `git_repo` : url of the repo you're cloning / testing
- `branch` : the branch you're testing

### job

- `job_name` : the name you wish your testing job to be associated with in databricks
- `task_key` : the key you want the testing job's single task to be associated with in databricks
- `dependencies` : python libraries you want installed on cluster for your job
- `runner` : determines what runner you'd like to use for your test. For brickproof's well-tested runner use `default` for a custom runner use `/path/to/my/runner.py`

A blank brickproof.toml file can be generated by running the `init` command.

## .nprc

The other configuration file needed to run brickproof testing jobs is the `.nprc` file. An example of which is shown below:

```
[default]
workspace=https://my-databricks-workspace.cloud.databricks.com
token=dummytoken

[secondary]
workspace=https://my-databricks-workspace2.cloud.databricks.com
token=dummytoken2
```

There are three parts to each section of the `.nprc` file. 

- profile: the portion in in brackets (`[default]` or `[secondary]`) in the example.
- `workspace`: the url of your databricks workspace where you'd like to run testing job
- `token`: a valid PAT token generated in your databricks workspace


## Contributing

See the Contributing doc for more details!


# Setup 

To setup, run the following:

```sh
./utility_scripts/dev_setup.sh
```
